treebank: library for TreeBank dataset
=======================

## Install

```
pip install --upgrade treebank
```

## Usage

```
import treebank
print(treebank.penn['train'])
print(treebank.penn['valid'])
print(treebank.penn['test'])
```
